@@ -1,4 +1,4 @@
-system "ruby -rubygems -I../../lib ../../bin/puma -p 10102 -C t1_conf.rb ../hello.ru &"
+system "ruby -rrubygems -Ilib bin/puma -p 10102 -C test/shell/t1_conf.rb test/rackup/hello.ru &"
 sleep 5
 system "curl http://localhost:10102/"
 
@@ -16,4 +16,3 @@ if log =~ %r!GET / HTTP/1\.1!
 else
   exit 1
 end
-
