@@ -22,41 +22,40 @@ class TestPumaServerSSL < Minitest::Test
 
   def setup
     return if DISABLE_SSL
-    @port = 3212
-    @host = "127.0.0.1"
+    port = UniquePort.call
+    host = "127.0.0.1"
 
-    @app = lambda { |env| [200, {}, [env['rack.url_scheme']]] }
+    app = lambda { |env| [200, {}, [env['rack.url_scheme']]] }
 
-    @ctx = Puma::MiniSSL::Context.new
+    ctx = Puma::MiniSSL::Context.new
 
     if Puma.jruby?
-      @ctx.keystore =  File.expand_path "../../examples/puma/keystore.jks", __FILE__
-      @ctx.keystore_pass = 'blahblah'
+      ctx.keystore =  File.expand_path "../../examples/puma/keystore.jks", __FILE__
+      ctx.keystore_pass = 'blahblah'
     else
-      @ctx.key =  File.expand_path "../../examples/puma/puma_keypair.pem", __FILE__
-      @ctx.cert = File.expand_path "../../examples/puma/cert_puma.pem", __FILE__
+      ctx.key  =  File.expand_path "../../examples/puma/puma_keypair.pem", __FILE__
+      ctx.cert = File.expand_path "../../examples/puma/cert_puma.pem", __FILE__
     end
 
-    @ctx.verify_mode = Puma::MiniSSL::VERIFY_NONE
+    ctx.verify_mode = Puma::MiniSSL::VERIFY_NONE
 
     @events = SSLEventsHelper.new STDOUT, STDERR
-    @server = Puma::Server.new @app, @events
-    @server.add_ssl_listener @host, @port, @ctx
+    @server = Puma::Server.new app, @events
+    @ssl_listener = @server.add_ssl_listener host, port, ctx
     @server.run
 
-    @http = Net::HTTP.new @host, @port
+    @http = Net::HTTP.new host, port
     @http.use_ssl = true
     @http.verify_mode = OpenSSL::SSL::VERIFY_NONE
   end
 
   def teardown
     return if DISABLE_SSL
+    @http.finish if @http.started?
     @server.stop(true)
   end
 
   def test_url_scheme_for_https
-    return if DISABLE_SSL
-
     body = nil
     @http.start do
       req = Net::HTTP::Get.new "/", {}
@@ -70,8 +69,6 @@ class TestPumaServerSSL < Minitest::Test
   end
 
   def test_very_large_return
-    return if DISABLE_SSL
-
     giant = "x" * 2056610
 
     @server.app = proc do
@@ -90,8 +87,6 @@ class TestPumaServerSSL < Minitest::Test
   end
 
   def test_form_submit
-    return if DISABLE_SSL
-
     body = nil
     @http.start do
       req = Net::HTTP::Post.new '/'
@@ -107,7 +102,6 @@ class TestPumaServerSSL < Minitest::Test
   end
 
   def test_ssl_v3_rejection
-    return if DISABLE_SSL
     @http.ssl_version='SSLv3'
     assert_raises(OpenSSL::SSL::SSLError) do
       @http.start do
@@ -115,7 +109,7 @@ class TestPumaServerSSL < Minitest::Test
       end
     end
     unless Puma.jruby?
-      assert_match("wrong version number", @events.error.message) if @events.error
+      assert_match(/wrong version number|no protocols available/, @events.error.message) if @events.error
     end
   end
 
@@ -125,38 +119,38 @@ end
 class TestPumaServerSSLClient < Minitest::Test
 
   def assert_ssl_client_error_match(error, subject=nil, &blk)
-    @port = 3212
-    @host = "127.0.0.1"
+    port = 3212
+    host = "127.0.0.1"
 
-    @app = lambda { |env| [200, {}, [env['rack.url_scheme']]] }
+    app = lambda { |env| [200, {}, [env['rack.url_scheme']]] }
 
-    @ctx = Puma::MiniSSL::Context.new
+    ctx = Puma::MiniSSL::Context.new
     if Puma.jruby?
-      @ctx.keystore =  File.expand_path "../../examples/puma/client-certs/keystore.jks", __FILE__
-      @ctx.keystore_pass = 'blahblah'
+      ctx.keystore =  File.expand_path "../../examples/puma/client-certs/keystore.jks", __FILE__
+      ctx.keystore_pass = 'blahblah'
     else
-      @ctx.key = File.expand_path "../../examples/puma/client-certs/server.key", __FILE__
-      @ctx.cert = File.expand_path "../../examples/puma/client-certs/server.crt", __FILE__
-      @ctx.ca = File.expand_path "../../examples/puma/client-certs/ca.crt", __FILE__
+      ctx.key = File.expand_path "../../examples/puma/client-certs/server.key", __FILE__
+      ctx.cert = File.expand_path "../../examples/puma/client-certs/server.crt", __FILE__
+      ctx.ca = File.expand_path "../../examples/puma/client-certs/ca.crt", __FILE__
     end
-    @ctx.verify_mode = Puma::MiniSSL::VERIFY_PEER | Puma::MiniSSL::VERIFY_FAIL_IF_NO_PEER_CERT
+    ctx.verify_mode = Puma::MiniSSL::VERIFY_PEER | Puma::MiniSSL::VERIFY_FAIL_IF_NO_PEER_CERT
 
     events = SSLEventsHelper.new STDOUT, STDERR
-    @server = Puma::Server.new @app, events
-    @server.add_ssl_listener @host, @port, @ctx
-    @server.run
+    server = Puma::Server.new app, events
+    ssl_listener = server.add_ssl_listener host, port, ctx
+    server.run
 
-    @http = Net::HTTP.new @host, @port
-    @http.use_ssl = true
-    @http.verify_mode = OpenSSL::SSL::VERIFY_NONE
+    http = Net::HTTP.new host, port
+    http.use_ssl = true
+    http.verify_mode = OpenSSL::SSL::VERIFY_NONE
 
-    blk.call(@http)
+    blk.call(http)
 
     client_error = false
     begin
-      @http.start do
+      http.start do
         req = Net::HTTP::Get.new "/", {}
-        @http.request(req)
+        http.request(req)
       end
     rescue OpenSSL::SSL::SSLError
       client_error = true
@@ -168,11 +162,11 @@ class TestPumaServerSSLClient < Minitest::Test
     # messages here
     unless Puma.jruby?
       assert_match error, events.error.message if error
-      assert_equal @host, events.addr if error
+      assert_equal host, events.addr if error
       assert_equal subject, events.cert.subject.to_s if subject
     end
-  ensure
-    @server.stop(true)
+
+    server.stop(true)
   end
 
   def test_verify_fail_if_no_client_cert
