@@ -1,12 +1,8 @@
-require 'minitest/autorun'
-require 'minitest/assertions'
+require_relative "helper"
 
-require 'puma/tcp_logger'
-require 'socket'
-require 'puma/server'
-require 'puma/events'
+require "puma/tcp_logger"
 
-class TestTCPLogger < Minitest::Unit::TestCase
+class TestTCPLogger < Minitest::Test
 
   def setup
     @events = Puma::Events.new STDOUT, STDERR
